@@ -74,6 +74,7 @@ static struct option {
 	{ "check-links",          0, OPTION_CHECK_LINKS },
 	{ "checkpoint-bytes",	  1, OPTION_CHECKPOINT_BYTES },
 	{ "chroot",               0, OPTION_CHROOT },
+	{ "configfile",		  1, OPTION_CONFIGFILE },
 	{ "confirmation",         0, 'w' },
 	{ "create",               0, 'c' },
 	{ "dereference",	  0, 'L' },
@@ -87,11 +88,13 @@ static struct option {
 	{ "file",                 1, 'f' },
 	{ "files-from",           1, 'T' },
 	{ "fsck",		  0, OPTION_FSCK },
+	{ "fsck-prune",		  0, OPTION_FSCK_PRUNE },
 	{ "help",                 0, OPTION_HELP },
 	{ "humanize-numbers",	  0, OPTION_HUMANIZE_NUMBERS },
 	{ "include",              1, OPTION_INCLUDE },
-	{ "interactive",          0, 'w' },
+	{ "insane-filesystems",	  0, OPTION_INSANE_FILESYSTEMS },
 	{ "insecure",             0, 'P' },
+	{ "interactive",          0, 'w' },
 	{ "keep-newer-files",     0, OPTION_KEEP_NEWER_FILES },
 	{ "keep-old-files",       0, 'k' },
 	{ "keyfile",		  1, OPTION_KEYFILE },
@@ -116,13 +119,16 @@ static struct option {
 	{ "no-aggressive-networking", 0, OPTION_NO_AGGRESSIVE_NETWORKING },
 	{ "no-config-exclude",	  0, OPTION_NO_CONFIG_EXCLUDE },
 	{ "no-config-include",	  0, OPTION_NO_CONFIG_INCLUDE },
+	{ "no-default-config",	  0, OPTION_NO_DEFAULT_CONFIG },
 	{ "no-disk-pause",	  0, OPTION_NO_DISK_PAUSE },
 	{ "no-humanize-numbers",  0, OPTION_NO_HUMANIZE_NUMBERS },
+	{ "no-insane-filesystems", 0, OPTION_NO_INSANE_FILESYSTEMS },
 	{ "no-maxbw",		  0, OPTION_NO_MAXBW },
 	{ "no-maxbw-rate-down",	  0, OPTION_NO_MAXBW_RATE_DOWN },
 	{ "no-maxbw-rate-up",	  0, OPTION_NO_MAXBW_RATE_UP },
 	{ "no-nodump",		  0, OPTION_NO_NODUMP },
 	{ "no-print-stats",	  0, OPTION_NO_PRINT_STATS },
+	{ "no-quiet",		  0, OPTION_NO_QUIET },
 	{ "no-recursion",         0, 'n' },
 	{ "no-same-owner",	  0, OPTION_NO_SAME_OWNER },
 	{ "no-same-permissions",  0, OPTION_NO_SAME_PERMISSIONS },
@@ -135,7 +141,9 @@ static struct option {
 	{ "one-file-system",	  0, OPTION_ONE_FILE_SYSTEM },
 	{ "preserve-permissions", 0, 'p' },
 	{ "print-stats",	  0, OPTION_PRINT_STATS },
+	{ "quiet",		  0, OPTION_QUIET },
 	{ "read-full-blocks",	  0, 'B' },
+	{ "recover",		  0, OPTION_RECOVER },
 	{ "same-owner",	          0, OPTION_SAME_OWNER },
 	{ "same-permissions",     0, 'p' },
 	{ "snaptime",		  1, OPTION_SNAPTIME },
@@ -189,7 +197,7 @@ static struct option {
  *
  * TODO: If we want to support arbitrary command-line options from -T
  * input (as GNU tar does), we may need to extend this to handle option
- * words from sources other than argv/arc.  I'm not really sure if I
+ * words from sources other than argv/argc.  I'm not really sure if I
  * like that feature of GNU tar, so it's certainly not a priority.
  */
 
