@@ -1,9 +1,8 @@
 #ifndef _STORAGE_H_
 #define _STORAGE_H_
 
-#include <sys/types.h>	/* Linux is broken and requires this for off_t. */
 #include <stdint.h>	/* uint8_t, uint64_t */
-#include <unistd.h>	/* off_t, size_t */
+#include <unistd.h>	/* size_t */
 
 #include "crypto.h"
 
@@ -40,6 +39,19 @@ int storage_read_file(STORAGE_R *, uint8_t *, size_t, char,
 int storage_read_file_alloc(STORAGE_R *, uint8_t **, size_t *, char,
     const uint8_t[32]);
 
+/**
+ * storage_read_file_callback(S, buf, buflen, class, name, callback, cookie):
+ * Read the file ${name} from class ${class} using the read cookie ${S}
+ * returned from storage_read_init.  If ${buf} is non-NULL, then read the
+ * file (which should be ${buflen} bytes in length} into ${buf}; otherwise
+ * malloc a buffer.  Invoke ${callback}(${cookie}, status, b, blen) when
+ * complete, where ${status} is 0, 1, 2, or -1 as per storage_read_file,
+ * ${b} is the buffer into which the data was read (which will be ${buf} if
+ * that value was non-NULL) and ${blen} is the length of the file.
+ */
+int storage_read_file_callback(STORAGE_R *, uint8_t *, size_t, char,
+    const uint8_t[32], int(*)(void *, int, uint8_t *, size_t), void *);
+
 /**
  * storage_read_free(S):
  * Close the read cookie ${S} and free any allocated memory.
@@ -48,7 +60,7 @@ void storage_read_free(STORAGE_R *);
 
 /**
  * storage_write_start(machinenum, lastseq, seqnum, dryrun):
- * Start a write transaction, presuming that ${lastseq} is the the sequence
+ * Start a write transaction, presuming that ${lastseq} is the sequence
  * number of the last committed transaction, or zeroes if there is no
  * previous transaction; and store the sequence number of the new transaction
  * into ${seqnum}.  If ${dryrun} is nonzero, perform a dry run.
@@ -96,7 +108,7 @@ void storage_write_free(STORAGE_W *);
 
 /**
  * storage_delete_start(machinenum, lastseq, seqnum):
- * Start a delete transaction, presuming that ${lastseq} is the the sequence
+ * Start a delete transaction, presuming that ${lastseq} is the sequence
  * number of the last committed transaction, or zeroes if there is no
  * previous transaction; and store the sequence number of the new transaction
  * into ${seqnum}.
@@ -104,11 +116,12 @@ void storage_write_free(STORAGE_W *);
 STORAGE_D * storage_delete_start(uint64_t, const uint8_t[32], uint8_t[32]);
 
 /**
- * storage_fsck_start(machinenum, seqnum):
+ * storage_fsck_start(machinenum, seqnum, readonly, whichkey):
  * Start a fsck transaction, and store the sequence number of said
- * transaction into ${seqnum}.
+ * transaction into ${seqnum}.  If ${whichkey} is zero, use the write key
+ * (in which case the transaction must be readonly).
  */
-STORAGE_D * storage_fsck_start(uint64_t, uint8_t[32]);
+STORAGE_D * storage_fsck_start(uint64_t, uint8_t[32], int, int);
 
 /**
  * storage_delete_file(S, class, name):
@@ -136,7 +149,7 @@ int storage_delete_end(STORAGE_D *);
 
 /**
  * storage_delete_free(S):
- * Free any memory allocated as part of the delete transcation associated
+ * Free any memory allocated as part of the delete transaction associated
  * with the cookie ${S}; the transaction will not be committed.
  */
 void storage_delete_free(STORAGE_D *);
@@ -159,6 +172,15 @@ int storage_transaction_checkpoint(uint64_t, const uint8_t[32],
  */
 int storage_transaction_commit(uint64_t, const uint8_t[32], uint8_t);
 
+/**
+ * storage_transaction_commitfromcheckpoint(machinenum, whichkey):
+ * If a write transaction is currently in progress and has a checkpoint,
+ * commit it.  The value ${whichkey} specifies a key which should be used
+ * to sign the commit request: 0 if the write key should be used, and 1 if
+ * the delete key should be used.
+ */
+int storage_transaction_commitfromcheckpoint(uint64_t, uint8_t);
+
 /**
  * storage_directory_read(machinenum, class, key, flist, nfiles):
  * Fetch a sorted list of files in the specified class.  If ${key} is 0, use
